Error

Enum Error 

pub enum Error {
Show 32 variants FeeEstimationFailed(String), FeeEstimationUnavailable, NoSpendableUtxos, AlreadyStarted, InvalidConfig(String), UnsupportedOnchain, UnknownFeeIndex(u32), Json(Error), AmountConversion(Error), Database(Error), Wallet(String), BitcoinRpc(Error), Esplora(String), Bip32(Error), KeyDerivation(KeyError), CouldNotSign, Path, Io(Error), KvStore(Error), VoutNotFound, SendIntentNotFound(Uuid), SendBatchNotFound(Uuid), DuplicateQuoteId(String), BatchFeeTooHigh { actual_fee: u64, max_fee: u64, }, EstimatedFeeTooHigh { estimated_fee: u64, max_fee: u64, }, NoValidFeeAllocation, DustOutput { amount: u64, dust_limit: u64, }, AmountBelowMinimumSend { amount: u64, min: u64, }, BatchAssignmentMissing { batch_id: Uuid, intent_id: Uuid, }, ReceiveIntentNotFound(Uuid), ReceiveAddressNotFound(String), BdkPersist,
}
CDK BDK onchain backend error

Variants



FeeEstimationFailed(String)

Fee estimation failed



FeeEstimationUnavailable

Fee estimation unavailable



NoSpendableUtxos

Wallet has no spendable UTXOs available for an onchain quote



AlreadyStarted

Start called but tasks are already running



InvalidConfig(String)

Invalid backend configuration



UnsupportedOnchain

Unsupported payment type for onchain backend



UnknownFeeIndex(u32)

Wallet selected a fee_index outside the configured BDK fee options.



Json(Error)

JSON error



AmountConversion(Error)

Amount conversion error



Database(Error)

Database error



Wallet(String)

Wallet error



BitcoinRpc(Error)

Bitcoin RPC error



Esplora(String)

Esplora error



Bip32(Error)

Bip32 key derivation error



KeyDerivation(KeyError)

Key derivation error



CouldNotSign

Could not sign transaction



Path

Path error



Io(Error)

IO error



KvStore(Error)

KV Store error



VoutNotFound

Could not find matching output vout in transaction



SendIntentNotFound(Uuid)

Send intent not found in storage



SendBatchNotFound(Uuid)

Send batch not found in storage



DuplicateQuoteId(String)

Send intent with quote id already exists in storage



BatchFeeTooHigh

Batch fee exceeds the combined max fee of all included intents

Fields

actual_fee: u64

Actual transaction fee in sats

max_fee: u64

Maximum combined fee from included intents



EstimatedFeeTooHigh

Current fee estimate exceeds the max fee accepted by a melt quote.

Fields

estimated_fee: u64

Current estimated fee reserve in sats

max_fee: u64

Maximum fee accepted by the quote in sats



NoValidFeeAllocation

No valid fee allocation exists for the batch



DustOutput

Requested recipient output is below the dust limit for its script type

Fields

amount: u64

Requested recipient amount in sats

dust_limit: u64

Minimum non-dust amount for the destination script in sats



AmountBelowMinimumSend

Requested send amount is below the backend’s configured minimum.

Fields

amount: u64

Requested recipient amount in sats

min: u64

Configured minimum send amount in sats



BatchAssignmentMissing

Batch record is missing an output assignment for one of its member intents.

This indicates a persistence invariant violation: every intent ID listed in a Signed/Broadcast batch must have a corresponding assignment entry.

Fields

batch_id: Uuid

Batch that is missing the assignment

intent_id: Uuid

Intent with no assignment entry



ReceiveIntentNotFound(Uuid)

Receive intent not found in storage



ReceiveAddressNotFound(String)

Receive address not found in storage



BdkPersist

Database

Implementations

Source

impl Error

pub fn is_transient(&self) -> bool

Returns true when the error is a transient network / upstream condition that is expected to resolve on retry.

This is used by the sync supervisor to decide whether to continue retrying on the next tick (transient) or to treat the failure as part of the backoff/restart policy (non-transient).