pub struct WalletTransactionInput {
pub txid: String,
pub vout: u32,
pub amount_sat: Option<u64>,
pub address: Option<String>,
}Expand description
An input spent by a wallet transaction.
Fields
txid: StringTransaction ID containing the previous output.
vout: u32Index of the previous output.
amount_sat: Option<u64>Value of the previous output in satoshis, when known.
address: Option<String>Address of the previous output, when it belongs to the wallet.